# deCONZ
Python library wrapping deCONZ rest api for Home-Assistant.

Currently supports lights, remotes, humidity sensors, light level sensors, motion sensors, pressure sensors and temperature sensors.

Generate an API key using utils.py/get_api_key, host, username and password are required parameters. Or follow snillevilla.se guide to get a key.

Only host address and API key are necessary for normal operations.

## Acknowledgements
* Mattias Flodins custom deCONZ component was a great source of inspiration.
* Maija Vilkina and her blog [Snillevilla](https://snillevilla.se/) has been a huge help in getting deCONZ up and running.
